==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/es_MX.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "El compartir de servidor a servidor no está habilitado en este servidor",
    "The mountpoint name contains invalid characters." : "El nombre del punto de montaje contiene caracteres inválidos.",
    "Not allowed to create a federated share with the same user server" : "No se permite crear un compartimiento federado con el mismo servidor de usuario",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido o no es de confianza",
    "Could not authenticate to remote share, password might be wrong" : "No se pudo autenticar para compartir remotamente, la contraseña puede estar incorrecta",
    "Storage not valid" : "Almacenamiento no válido",
    "Couldn't add remote share" : "No se pudo agregar compartimiento remoto",
    "Shared with you" : "Compartido contigo",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido mediante vínculo",
    "Uploading..." : "Subiendo...",
    "Nothing shared with you yet" : "No hay nada compartido con usted todavía",
    "Files and folders others share with you will show up here" : "Los archivos y carpetas que otros compartan con usted aparecerán aquí",
    "Nothing shared yet" : "No se ha compartido nada",
    "Files and folders you share will show up here" : "Los archivos y carpetas que sean compartidas se mostrarán aquí",
    "No shared links" : "No hay vínculos compartidos",
    "Files and folders you share by link will show up here" : "Los archivos y carpetas que sean compartidas mediante vínculos serán mostrados aquí",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Quiere agregar el contenido compartido remoto {name} de {owner}@{remote}?",
    "Cancel" : "Cancelar",
    "You can upload into this folder" : "Puedes subir contenido a esta carpeta",
    "No ownCloud installation (7 or higher) found at {remote}" : "No se encontró ninguna instalación ownCloud (7 o mayor) en {remote}",
    "Invalid ownCloud url" : "URL de ownCloud inválido",
    "Share" : "Compartir",
    "No expiration date set" : "No se estableció ninguna fecha de expiración",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartir",
    "Share API is disabled" : "El API para Compartir está deshabilitado",
    "Please specify a valid user" : "Por favor especifique un usuario válido",
    "Group sharing is disabled by the administrator" : "La función para Compartir en Grupo ha sido deshabilitada por el administrador",
    "Please specify a valid group" : "Por favor especifique un grupo válido",
    "Public link expired" : "Vínculo público expirado",
    "Shared by %2$s" : "Compartido por %2$s",
    "Shares" : "Veces compartido",
    "This share is password-protected" : "Este elemento compartido esta protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña introducida es errónea. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "No se encontraron entradas en esta carpeta",
    "Name" : "Nombre",
    "Expiration date" : "Fecha de caducidad",
    "Sorry, this link doesn’t seem to work anymore." : "Lo siento, este enlace al parecer ya no funciona.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió el enlace.",
    "%s is publicly shared" : "%s está compartido públicamente",
    "Add to your ownCloud" : "Agregar a tu ownCloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enlace directo"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/es_MX.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "El compartir de servidor a servidor no está habilitado en este servidor",
    "The mountpoint name contains invalid characters." : "El nombre del punto de montaje contiene caracteres inválidos.",
    "Not allowed to create a federated share with the same user server" : "No se permite crear un compartimiento federado con el mismo servidor de usuario",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido o no es de confianza",
    "Could not authenticate to remote share, password might be wrong" : "No se pudo autenticar para compartir remotamente, la contraseña puede estar incorrecta",
    "Storage not valid" : "Almacenamiento no válido",
    "Couldn't add remote share" : "No se pudo agregar compartimiento remoto",
    "Shared with you" : "Compartido contigo",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido mediante vínculo",
    "Uploading..." : "Subiendo...",
    "Nothing shared with you yet" : "No hay nada compartido con usted todavía",
    "Files and folders others share with you will show up here" : "Los archivos y carpetas que otros compartan con usted aparecerán aquí",
    "Nothing shared yet" : "No se ha compartido nada",
    "Files and folders you share will show up here" : "Los archivos y carpetas que sean compartidas se mostrarán aquí",
    "No shared links" : "No hay vínculos compartidos",
    "Files and folders you share by link will show up here" : "Los archivos y carpetas que sean compartidas mediante vínculos serán mostrados aquí",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Quiere agregar el contenido compartido remoto {name} de {owner}@{remote}?",
    "Cancel" : "Cancelar",
    "You can upload into this folder" : "Puedes subir contenido a esta carpeta",
    "No ownCloud installation (7 or higher) found at {remote}" : "No se encontró ninguna instalación ownCloud (7 o mayor) en {remote}",
    "Invalid ownCloud url" : "URL de ownCloud inválido",
    "Share" : "Compartir",
    "No expiration date set" : "No se estableció ninguna fecha de expiración",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartir",
    "Share API is disabled" : "El API para Compartir está deshabilitado",
    "Please specify a valid user" : "Por favor especifique un usuario válido",
    "Group sharing is disabled by the administrator" : "La función para Compartir en Grupo ha sido deshabilitada por el administrador",
    "Please specify a valid group" : "Por favor especifique un grupo válido",
    "Public link expired" : "Vínculo público expirado",
    "Shared by %2$s" : "Compartido por %2$s",
    "Shares" : "Veces compartido",
    "This share is password-protected" : "Este elemento compartido esta protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña introducida es errónea. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "No se encontraron entradas en esta carpeta",
    "Name" : "Nombre",
    "Expiration date" : "Fecha de caducidad",
    "Sorry, this link doesn’t seem to work anymore." : "Lo siento, este enlace al parecer ya no funciona.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió el enlace.",
    "%s is publicly shared" : "%s está compartido públicamente",
    "Add to your ownCloud" : "Agregar a tu ownCloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enlace directo",
    "Pending" : "Pendiente",
    "Declined" : "Denegado"
},
"nplurals=2; plural=(n != 1);");
